/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
module dwt.widgets.typedlistener;

/**	 
 * Instances of this class are <em>internal SWT implementation</em>
 * objects which provide a mapping between the typed and untyped 
 * listener mechanisms that SWT supports.
 * <p>
 * <b>IMPORTANT:</b> This class is <em>not</em> part of the SWT
 * public API. It is marked public only so that it can be shared
 * within the packages provided by SWT. It should never be
 * referenced from application code.
 * </p>
 *
 * @see Listener
 */
private import dwt.widgets.listener;
private {
	import dwt.dwt;
	import dwt.events.armevent;
	import dwt.events.armlistener;
	import dwt.events.controlevent;
	import dwt.events.controllistener;
	import dwt.events.disposeevent;
	import dwt.events.disposelistener;
	import dwt.events.focusevent;
	import dwt.events.focuslistener;
	import dwt.events.helpevent;
	import dwt.events.helplistener;
	import dwt.events.keyevent;
	import dwt.events.keylistener;
	import dwt.events.menuevent;
	import dwt.events.menulistener;
	import dwt.events.modifyevent;
	import dwt.events.modifylistener;
	import dwt.events.mouseevent;
	import dwt.events.mouselistener;
	import dwt.events.mousemovelistener;
	import dwt.events.mousetracklistener;
	import dwt.events.paintevent;
	import dwt.events.paintlistener;
	import dwt.events.selectionevent;
	import dwt.events.selectionlistener;
	import dwt.events.shellevent;
	import dwt.events.shelllistener;
	import dwt.events.traverseevent;
	import dwt.events.traverselistener;
	import dwt.events.treeevent;
	import dwt.events.treelistener;
	import dwt.events.verifyevent;
	import dwt.events.verifylistener;
	import dwt.internal.dwteventlistener;

	import dwt.widgets.event;
} 
public class TypedListener : Listener {


	
	/**
	 * The receiver's event listener
	 */
	protected DWTEventListener eventListener;

/**
 * Constructs a new instance of this class for the given event listener.
 * <p>
 * <b>IMPORTANT:</b> This method is <em>not</em> part of the SWT
 * public API. It is marked public only so that it can be shared
 * within the packages provided by SWT. It should never be
 * referenced from application code.
 * </p>
 *
 * @param listener the event listener to store in the receiver
 */
public this(DWTEventListener listener) {
	eventListener = listener;
}

/**
 * Returns the receiver's event listener.
 * <p>
 * <b>IMPORTANT:</b> This method is <em>not</em> part of the SWT
 * public API. It is marked public only so that it can be shared
 * within the packages provided by SWT. It should never be
 * referenced from application code.
 * </p>
 *
 * @return the receiver's event listener
 */
public DWTEventListener getEventListener () {
	return eventListener;
}

/**
 * Handles the given event.
 * <p>
 * <b>IMPORTANT:</b> This method is <em>not</em> part of the SWT
 * public API. It is marked public only so that it can be shared
 * within the packages provided by SWT. It should never be
 * referenced from application code.
 * </p>
 */
public void handleEvent (Event e) {
	switch (e.type) {
		case DWT.Paint: {
			/* Field set by Control */
			PaintEvent event = new PaintEvent (e);
			(cast(PaintListener) eventListener).paintControl (event);
			e.gc = event.gc;
			break;
		}			
		case DWT.Selection: {
			/* Fields set by Sash */
			SelectionEvent event = new SelectionEvent (e);
			(cast(SelectionListener) eventListener).widgetSelected (event);			
			e.x = event.x;
			e.y = event.y;
			e.doit = event.doit;
			break;
		}
		case DWT.DefaultSelection: {
			(cast(SelectionListener)eventListener).widgetDefaultSelected(new SelectionEvent(e));
			break;
		}
		case DWT.Dispose: {
			(cast(DisposeListener) eventListener).widgetDisposed(new DisposeEvent(e));
			break;
		}
		case DWT.FocusIn: {
			(cast(FocusListener) eventListener).focusGained(new FocusEvent(e));
			break;
		}
		case DWT.FocusOut: {
			(cast(FocusListener) eventListener).focusLost(new FocusEvent(e));
			break;
		}
		case DWT.Hide: {
			(cast(MenuListener) eventListener).menuHidden(new MenuEvent(e));
			break;
		}
		case DWT.Show: {
			(cast(MenuListener) eventListener).menuShown(new MenuEvent(e));
			break;
		}
		case DWT.KeyDown: {
			KeyEvent event = new KeyEvent(e);
			(cast(KeyListener) eventListener).keyPressed(event);
			e.doit = event.doit;
			break;
		}
		case DWT.KeyUp: {
			KeyEvent event = new KeyEvent(e);
			(cast(KeyListener) eventListener).keyReleased(event);
			e.doit = event.doit;
			break;
		}
		case DWT.MouseDown: {
			(cast(MouseListener) eventListener).mouseDown(new MouseEvent(e));
			break;
		}
		case DWT.MouseUp: {
			(cast(MouseListener) eventListener).mouseUp(new MouseEvent(e));
			break;
		}
		case DWT.MouseDoubleClick: {
			(cast(MouseListener) eventListener).mouseDoubleClick(new MouseEvent(e));
			break;
		}
		case DWT.MouseMove: {
			(cast(MouseMoveListener) eventListener).mouseMove(new MouseEvent(e));
			return;
		}
		case DWT.Resize: {
			(cast(ControlListener) eventListener).controlResized(new ControlEvent(e));
			break;
		}
		case DWT.Move: {
			(cast(ControlListener) eventListener).controlMoved(new ControlEvent(e));
			break;
		}
		case DWT.Close: {
			/* Fields set by Decorations */
			ShellEvent event = new ShellEvent (e);
			(cast(ShellListener) eventListener).shellClosed(event);
			e.doit = event.doit;
			break;
		}
		case DWT.Activate: {
			(cast(ShellListener) eventListener).shellActivated(new ShellEvent(e));
			break;
		}
		case DWT.Deactivate: {
			(cast(ShellListener) eventListener).shellDeactivated(new ShellEvent(e));
			break;
		}
		case DWT.Iconify: {
			(cast(ShellListener) eventListener).shellIconified(new ShellEvent(e));
			break;
		}
		case DWT.Deiconify: {
			(cast(ShellListener) eventListener).shellDeiconified(new ShellEvent(e));
			break;
		}
		case DWT.Expand: {
			(cast(TreeListener) eventListener).treeExpanded(new TreeEvent(e));
			break;
		}
		case DWT.Collapse: {
			(cast(TreeListener) eventListener).treeCollapsed(new TreeEvent(e));
			break;
		}
		case DWT.Modify: {
			(cast(ModifyListener) eventListener).modifyText(new ModifyEvent(e));
			break;
		}
		case DWT.Verify: {
			/* Fields set by Text, RichText */
			VerifyEvent event = new VerifyEvent (e);
			(cast(VerifyListener) eventListener).verifyText (event);
			e.text = event.text;
			e.doit = event.doit;
			break;
		}
		case DWT.Help: {
			(cast(HelpListener) eventListener).helpRequested (new HelpEvent (e));
			break;
		}
		case DWT.Arm: {
			(cast(ArmListener) eventListener).widgetArmed (new ArmEvent (e));
			break;
		}
		case DWT.MouseExit: {
			(cast(MouseTrackListener) eventListener).mouseExit (new MouseEvent (e));
			break;
		}
		case DWT.MouseEnter: {
			(cast(MouseTrackListener) eventListener).mouseEnter (new MouseEvent (e));
			break;
		}
		case DWT.MouseHover: {
			(cast(MouseTrackListener) eventListener).mouseHover (new MouseEvent (e));
			break;
		}
		case DWT.Traverse: {
			/* Fields set by Control */
			TraverseEvent event = new TraverseEvent (e);
			(cast(TraverseListener) eventListener).keyTraversed (event);
			e.detail = event.detail;
			e.doit = event.doit;
			break;
		}
		
	}
}

}
