# Makefile to build the D Window Toolkit (dwt) for Win32
# 
# USING:  \dm\bin\make.exe (digital mars make)
#
# TARGETS:
#	make or make all
#		Builds the dwt.lib
#	make clean
# 		Delete files created during the build process
#
# NOTES:	This makefile is designed for digitalmars make.exe and lib.exe
#		 	on the Win32 platform.  A separate linux makefile is available
#			in this directory.
#
# Makefile by John Reimer
# Date: 2004-02-19
# Updated: 2004-07-25

CFLAGS=-g -mn -6 -r
DFLAGS=-v -version=Win32 -version=Unicode

CC=sc
DMD=\dmd\bin\dmd
LIB=\dm\bin\lib

.c.obj:
	$(CC) -c $(CFLAGS) $*

.cpp.obj:
	$(CC) -c $(CFLAGS) $*

.d.obj:
	$(DMD) -c $(DFLAGS) $*
	
.asm.obj:
	$(CC) -c $*
	
targets : dwt.lib

#########################################################
# DWT Object structure

OBJ_DWT_GRAPHICS= IDrawable.obj color.obj cursor.obj device.obj devicedata.obj font.obj \
	fontdata.obj fontmetrics.obj gc.obj gcdata.obj image.obj imagedata.obj \
	imageloader.obj palettedata.obj point.obj rectangle.obj region.obj rgb.obj
	
OBJ_DWT_INTERNAL_IMAGE=

OBJ_DWT_INTERNAL_OLE=

OBJ_DWT_INTERNAL_WIN32= func.obj os.obj tchar.obj types.obj 

OBJ_DWT_INTERNAL= callback.obj cloneablecompatibility.obj compatibility.obj \
	dwteventlistener.obj dwteventobject.obj library.obj platform.obj \
	serializablecompatibility.obj ttypes.obj

OBJ_DWT_UTIL= eventlistener.obj eventobject.obj runnable.obj string.obj \
	system.obj thread.obj throwable.obj util.obj

OBJ_DWT_WIDGETS= button.obj canvas.obj caret.obj composite.obj control.obj \
	decorations.obj display.obj event.obj eventtable.obj imagelist.obj \
	item.obj layout.obj listener.obj menu.obj menuitem.obj monitor.obj \
	runnablelock.obj scrollable.obj scrollbar.obj shell.obj synchronizer.obj \
	typedlistener.obj widget.obj

OBJ_DWT_EVENTS= armevent.obj armlistener.obj controladapter.obj controlevent.obj \
	controllistener.obj disposeevent.obj disposelistener.obj focusadapter.obj \
	focuslistener.obj helpevent.obj helplistener.obj keyadapter.obj keyevent.obj \
	keylistener.obj menuadapter.obj menuevent.obj menulistener.obj modifyevent.obj \
	modifylistener.obj mouseadapter.obj mouseevent.obj mouselistener.obj \
	mousemovelistener.obj mousetrackadapter.obj mousetracklistener.obj \
	paintevent.obj paintlistener.obj selectionadapter.obj selectionevent.obj \
	selectionlistener.obj shelladapter.obj shellevent.obj shelllistener.obj \
	traverseevent.obj traverselistener.obj treeadapter.obj treeevent.obj \
	treelistener.obj typedevent.obj verifyevent.obj verifylistener.obj
	
OBJ_DWT_ACCESSIBLE= acc.obj
	
OBJ_DWT= dwt.obj

OBJS= $(OBJ_DWT) \
	  $(OBJ_DWT_UTIL) \
	  $(OBJ_DWT_INTERNAL) \
	  $(OBJ_DWT_INTERNAL_WIN32) \
	  $(OBJ_DWT_EVENTS) \
	  $(OBJ_DWT_ACCESSIBLE) \
	  $(OBJ_DWT_GRAPHICS) \
	  $(OBJ_DWT_WIDGETS) \


##############################################################################
# DWT Source Structure

SRC_DWT= \
	dwt/dwt.d

SRC_DWT_ACCESSIBILITY= \
	dwt/accessibility/acc.d
	
# dwt\accessibility\accessible.d

SRC_DWT_GRAPHICS= \
	dwt/graphics/IDrawable.d \
	dwt/graphics/color.d \
	dwt/graphics/cursor.d \
	dwt/graphics/device.d  \
  	dwt/graphics/devicedata.d \
 	dwt/graphics/font.d \
  	dwt/graphics/fontdata.d \
  	dwt/graphics/fontmetrics.d \
	dwt/graphics/gc.d \
	dwt/graphics/gcdata.d \
  	dwt/graphics/image.d \
  	dwt/graphics/imagedata.d \
  	dwt/graphics/imageloader.d \
 	dwt/graphics/palettedata.d \
	dwt/graphics/point.d \
	dwt/graphics/rectangle.d \
	dwt/graphics/region.d \
	dwt/graphics/rgb.d 
	
SRC_DWT_INTERNAL_IMAGE=
SRC_DWT_INTERNAL_OLE=

SRC_DWT_INTERNAL = \
	dwt/internal/callback.d \
	dwt/internal/cloneablecompatibility.d \
	dwt/internal/compatibility.d \
	dwt/internal/dwteventlistener.d \
	dwt/internal/dwteventobject.d \
	dwt/internal/library.d \
	dwt/internal/platform.d \
	dwt/internal/serializablecompatibility.d \
	dwt/internal/ttypes.d \

SRC_DWT_INTERNAL_WIN32= \
	dwt/internal/win32/func.d \
	dwt/internal/win32/os.d \
	dwt/internal/win32/tchar.d \
	dwt/internal/win32/types.d 

SRC_DWT_UTIL = \
	dwt/util/eventlistener.d \
	dwt/util/eventobject.d \
	dwt/util/runnable.d \
	dwt/util/string.d \
	dwt/util/system.d \
	dwt/util/thread.d \
	dwt/util/throwable.d \
	dwt/util/util.d

SRC_DWT_WIDGETS = \
	dwt/widgets/button.d \
	dwt/widgets/canvas.d \
	dwt/widgets/caret.d \
	dwt/widgets/composite.d \
	dwt/widgets/control.d \
	dwt/widgets/decorations.d \
	dwt/widgets/display.d \
	dwt/widgets/event.d \
	dwt/widgets/eventtable.d \
	dwt/widgets/imagelist.d \
	dwt/widgets/item.d \
	dwt/widgets/layout.d \
	dwt/widgets/listener.d \
	dwt/widgets/menu.d \
	dwt/widgets/menuitem.d \
	dwt/widgets/monitor.d \
	dwt/widgets/runnablelock.d \
	dwt/widgets/scrollable.d \
	dwt/widgets/scrollbar.d \
	dwt/widgets/shell.d \
	dwt/widgets/synchronizer.d \
	dwt/widgets/typedlistener.d \
#	dwt/widgets/table.d \
#	dwt/widgets/tablecolumn.d \
#	dwt/widgets/tableitem.d \
#	dwt/widgets/text.d \
#	dwt/widgets/toolbar.d \
#	dwt/widgets/toolitem.d \
#	dwt/widgets/tracker.d \
#	dwt/widgets/tree.d \
#	dwt/widgets/treeitem.d \
	dwt/widgets/widget.d

	
SRC_DWT_EVENTS = dwt/events/armevent.d \
	dwt/events/armlistener.d \
	dwt/events/controladapter.d \
	dwt/events/controlevent.d \
	dwt/events/controllistener.d \
	dwt/events/disposeevent.d \
	dwt/events/disposelistener.d \
	dwt/events/focusadapter.d \
	dwt/events/focusevent.d \
	dwt/events/focuslistener.d \
	dwt/events/helpevent.d \
	dwt/events/helplistener.d \
	dwt/events/keyadapter.d \
	dwt/events/keyevent.d \
	dwt/events/keylistener.d \
	dwt/events/menuadapter.d \
	dwt/events/menuevent.d \
	dwt/events/menulistener.d \
	dwt/events/modifyevent.d \
	dwt/events/modifylistener.d \
	dwt/events/mouseadapter.d \
	dwt/events/mouseevent.d \
	dwt/events/mouselistener.d \
	dwt/events/mousemovelistener.d \
	dwt/events/mousetrackadapter.d \
	dwt/events/mousetracklistener.d \
	dwt/events/paintevent.d \
	dwt/events/paintlistener.d \
	dwt/events/selectionadapter.d \
	dwt/events/selectionevent.d \
	dwt/events/selectionlistener.d \
	dwt/events/shelladapter.d \
	dwt/events/shellevent.d \
	dwt/events/shelllistener.d \
	dwt/events/traverseevent.d \
	dwt/events/traverselistener.d \
	dwt/events/treeadapter.d \
	dwt/events/treeevent.d \
	dwt/events/treelistener.d \
	dwt/events/typedevent.d \
	dwt/events/verifyevent.d \
	dwt/events/verifylistener.d
	
SRC=  $(SRC_DWT) \
	  $(SRC_DWT_UTIL) \
	  $(SRC_DWT_INTERNAL) \
	  $(SRC_DWT_INTERNAL_WIN32) \
	  $(SRC_DWT_EVENTS) \
	  $(SRC_DWT_ACCESSIBILITY) \
	  $(SRC_DWT_GRAPHICS) \
	  $(SRC_DWT_WIDGETS) \

dwt.lib : $(OBJS) 
	$(LIB) -c dwt.lib $(OBJS) 

# dwt.lib : 
#	$(DMD) -c $(DFLAGS) $(SRC)	
	
##########################################################################
# Note: single step compiling of this project currently doesn't work
# because of forward referencing issues.

# ######### dwt.graphics ##########

IDrawable.obj : dwt\graphics\IDrawable.d
	$(DMD) -c $(DFLAGS) dwt\graphics\IDrawable.d

color.obj : dwt\graphics\color.d
	$(DMD) -c $(DFLAGS) dwt\graphics\color.d 

cursor.obj : dwt\graphics\cursor.d
	$(DMD) -c $(DFLAGS) dwt\graphics\cursor.d
	
device.obj : dwt\graphics\device.d
	$(DMD) -c $(DFLAGS) dwt\graphics\device.d

devicedata.obj : dwt\graphics\devicedata.d
	$(DMD) -c $(DFLAGS) dwt\graphics\devicedata.d

font.obj : dwt\graphics\font.d
	$(DMD) -c $(DFLAGS) dwt\graphics\font.d

fontdata.obj : dwt\graphics\fontdata.d
	$(DMD) -c $(DFLAGS) dwt\graphics\fontdata.d	

fontmetrics.obj : dwt\graphics\fontmetrics.d
	$(DMD) -c $(DFLAGS) dwt\graphics\fontmetrics.d

gc.obj : dwt\graphics\gc.d
	$(DMD) -c $(DFLAGS) dwt\graphics\gc.d
	
gcdata.obj : dwt\graphics\gcdata.d
	$(DMD) -c $(DFLAGS) dwt\graphics\gcdata.d

image.obj : dwt\graphics\image.d
	$(DMD) -c $(DFLAGS) dwt\graphics\image.d
	
imagedata.obj : dwt\graphics\imagedata.d
	$(DMD) -c $(DFLAGS) dwt\graphics\imagedata.d

imageloader.obj : dwt\graphics\imageloader.d
	$(DMD) -c $(DFLAGS) dwt\graphics\imageloader.d
	
palettedata.obj : dwt\graphics\palettedata.d
	$(DMD) -c $(DFLAGS) dwt\graphics\palettedata.d

point.obj : dwt\graphics\point.d
	$(DMD) -c $(DFLAGS) dwt\graphics\point.d
	
rectangle.obj : dwt\graphics\rectangle.d
	$(DMD) -c $(DFLAGS) dwt\graphics\rectangle.d
	
region.obj : dwt\graphics\region.d
	$(DMD) -c $(DFLAGS) dwt\graphics\region.d

rgb.obj : dwt\graphics\rgb.d
	$(DMD) -c $(DFLAGS) dwt\graphics\rgb.d
	
# ######## dwt.internal.win32 ###########

func.obj : dwt\internal\win32\func.d
	$(DMD) -c $(DFLAGS) dwt\internal\win32\func.d

os.obj : dwt\internal\win32\os.d
	$(DMD) -c $(DFLAGS) dwt\internal\win32\os.d
	
tchar.obj : dwt\internal\win32\tchar.d
	$(DMD) -c $(DFLAGS) dwt\internal\win32\tchar.d

types.obj : dwt\internal\win32\types.d
	$(DMD) -c $(DFLAGS) dwt\internal\win32\types.d

	
# ######### dwt.internal ##########

callback.obj : dwt\internal\callback.d
	$(DMD) -c $(DFLAGS) dwt\internal\callback.d

cloneablecompatibility.obj : dwt\internal\cloneablecompatibility.d
	$(DMD) -c $(DFLAGS) dwt\internal\cloneablecompatibility.d
	
compatibility.obj : dwt\internal\compatibility.d
	$(DMD) -c $(DFLAGS) dwt\internal\compatibility.d

dwteventlistener.obj : dwt\internal\dwteventlistener.d
	$(DMD) -c $(DFLAGS) dwt\internal\dwteventlistener.d

dwteventobject.obj : dwt\internal\dwteventobject.d
	$(DMD) -c $(DFLAGS) dwt\internal\dwteventobject.d
	
library.obj : dwt\internal\library.d
	$(DMD) -c $(DFLAGS) dwt\internal\library.d
	
platform.obj : dwt\internal\platform.d
	$(DMD) -c $(DFLAGS) dwt\internal\platform.d

serializablecompatibility.obj : dwt\internal\serializablecompatibility.d
	$(DMD) -c $(DFLAGS) dwt\internal\serializablecompatibility.d
	
ttypes.obj : dwt\internal\ttypes.d
	$(DMD) -c $(DFLAGS) dwt\internal\ttypes.d
	
# ########## dwt.util ##########

eventlistener.obj : dwt\util\eventlistener.d
	$(DMD) -c $(DFLAGS) dwt\util\eventlistener.d

eventobject.obj : dwt\util\eventobject.d
	$(DMD) -c $(DFLAGS) dwt\util\eventobject.d
	
runnable.obj : dwt\util\runnable.d
	$(DMD) -c $(DFLAGS) dwt\util\runnable.d
	
string.obj : dwt\util\string.d
	$(DMD) -c $(DFLAGS) dwt\util\string.d
	
system.obj : dwt\util\system.d
	$(DMD) -c $(DFLAGS) dwt\util\system.d
	
thread.obj : dwt\util\thread.d
	$(DMD) -c $(DFLAGS) dwt\util\thread.d

throwable.obj : dwt\util\throwable.d
	$(DMD) -c $(DFLAGS) dwt\util\throwable.d
	
util.obj : dwt\util\util.d
	$(DMD) -c $(DFLAGS) dwt\util\util.d
	
# ########## dwt.widgets ##########

button.obj : dwt\widgets\button.d
	$(DMD) -c $(DFLAGS) dwt\widgets\button.d 
	
canvas.obj : dwt\widgets\canvas.d
	$(DMD) -c $(DFLAGS) dwt\widgets\canvas.d
	
caret.obj : dwt\widgets\caret.d
	$(DMD) -c $(DFLAGS) dwt\widgets\caret.d
	
composite.obj : dwt\widgets\composite.d
	$(DMD) -c $(DFLAGS) dwt\widgets\composite.d

control.obj : dwt\widgets\control.d
	$(DMD) -c $(DFLAGS) dwt\widgets\control.d
	
decorations.obj : dwt\widgets\decorations.d
	$(DMD) -c $(DFLAGS) dwt\widgets\decorations.d
	
display.obj : dwt\widgets\display.d
	$(DMD) -c $(DFLAGS) dwt\widgets\display.d
	
event.obj : dwt\widgets\event.d
	$(DMD) -c $(DFLAGS) dwt\widgets\event.d

eventtable.obj : dwt\widgets\eventtable.d
	$(DMD) -c $(DFLAGS) dwt\widgets\eventtable.d
	
imagelist.obj : dwt\widgets\imagelist.d
	$(DMD) -c $(DFLAGS) dwt\widgets\imagelist.d
	
item.obj : dwt\widgets\item.d
	$(DMD) -c $(DFLAGS) dwt\widgets\item.d

layout.obj : dwt\widgets\layout.d
	$(DMD) -c $(DFLAGS) dwt\widgets\layout.d

listener.obj : dwt\widgets\listener.d
	$(DMD) -c $(DFLAGS) dwt\widgets\listener.d	

menu.obj : dwt\widgets\menu.d
	$(DMD) -c $(DFLAGS) dwt\widgets\menu.d

menuitem.obj : dwt\widgets\menuitem.d
	$(DMD) -c $(DFLAGS) dwt\widgets\menuitem.d

monitor.obj : dwt\widgets\monitor.d
	$(DMD) -c $(DFLAGS) dwt\widgets\monitor.d

runnablelock.obj : dwt\widgets\runnablelock.d
	$(DMD) -c $(DFLAGS) dwt\widgets\runnablelock.d	
	
scrollable.obj : dwt\widgets\scrollable.d
	$(DMD) -c $(DFLAGS) dwt\widgets\scrollable.d
	
scrollbar.obj : dwt\widgets\scrollbar.d
	$(DMD) -c $(DFLAGS) dwt\widgets\scrollbar.d
	
shell.obj : dwt\widgets\shell.d
	$(DMD) -c $(DFLAGS) dwt\widgets\shell.d

synchronizer.obj : dwt\widgets\synchronizer.d
	$(DMD) -c $(DFLAGS) dwt\widgets\synchronizer.d

typedlistener.obj : dwt\widgets\typedlistener.d
	$(DMD) -c $(DFLAGS) dwt\widgets\typedlistener.d
	
widget.obj : dwt\widgets\widget.d
	$(DMD) -c $(DFLAGS) dwt\widgets\widget.d

# ####### Events #############

armevent.obj : dwt\events\armevent.d
	$(DMD) -c $(DFLAGS) dwt\events\armevent.d
	
armlistener.obj : dwt\events\armlistener.d
	$(DMD) -c $(DFLAGS) dwt\events\armlistener.d

controladapter.obj : dwt\events\controladapter.d
	$(DMD) -c $(DFLAGS) dwt\events\controladapter.d
	
controlevent.obj : dwt\events\controlevent.d
	$(DMD) -c $(DFLAGS) dwt\events\controlevent.d
	
controllistener.obj : dwt\events\controllistener.d
	$(DMD) -c $(DFLAGS) dwt\events\controllistener.d
	
disposeevent.obj : dwt\events\disposeevent.d
	$(DMD) -c $(DFLAGS) dwt\events\disposeevent.d

disposelistener.obj : dwt\events\disposelistener.d
	$(DMD) -c $(DFLAGS) dwt\events\disposelistener.d
	
focusadapter.obj : dwt\events\focusadapter.d
	$(DMD) -c $(DFLAGS) dwt\events\focusadapter.d
	
focusevent.obj : dwt\events\focusevent.d
	$(DMD) -c $(DFLAGS) dwt\events\focusevent.d
	
focuslistener.obj : dwt\events\focuslistener.d
	$(DMD) -c $(DFLAGS) dwt\events\focuslistener.d

helpevent.obj : dwt\events\helpevent.d
	$(DMD) -c $(DFLAGS) dwt\events\helpevent.d
	
helplistener.obj : dwt\events\helplistener.d
	$(DMD) -c $(DFLAGS) dwt\events\helplistener.d
	
keyadapter.obj : dwt\events\keyadapter.d
	$(DMD) -c $(DFLAGS) dwt\events\keyadapter.d
	
keyevent.obj : dwt\events\keyevent.d
	$(DMD) -c $(DFLAGS) dwt\events\keyevent.d

keylistener.obj : dwt\events\keylistener.d
	$(DMD) -c $(DFLAGS) dwt\events\keylistener.d
	
menuadapter.obj : dwt\events\menuadapter.d
	$(DMD) -c $(DFLAGS) dwt\events\menuadapter.d
	
menuevent.obj : dwt\events\menuevent.d
	$(DMD) -c $(DFLAGS) dwt\events\menuevent.d
	
menulistener.obj : dwt\events\menulistener.d
	$(DMD) -c $(DFLAGS) dwt\events\menulistener.d

modifyevent.obj : dwt\events\modifyevent.d
	$(DMD) -c $(DFLAGS) dwt\events\modifyevent.d
	
modifylistener.obj : dwt\events\modifylistener.d
	$(DMD) -c $(DFLAGS) dwt\events\modifylistener.d
	
mouseadapter.obj : dwt\events\mouseadapter.d
	$(DMD) -c $(DFLAGS) dwt\events\mouseadapter.d
	
mouseevent.obj : dwt\events\mouseevent.d
	$(DMD) -c $(DFLAGS) dwt\events\mouseevent.d

mouselistener.obj : dwt\events\mouselistener.d
	$(DMD) -c $(DFLAGS) dwt\events\mouselistener.d
	
mousemovelistener.obj : dwt\events\mousemovelistener.d
	$(DMD) -c $(DFLAGS) dwt\events\mousemovelistener.d
	
mousetrackadapter.obj : dwt\events\mousetrackadapter.d
	$(DMD) -c $(DFLAGS) dwt\events\mousetrackadapter.d
	
mousetracklistener.obj : dwt\events\mousetracklistener.d
	$(DMD) -c $(DFLAGS) dwt\events\mousetracklistener.d

paintevent.obj : dwt\events\paintevent.d
	$(DMD) -c $(DFLAGS) dwt\events\paintevent.d
	
paintlistener.obj : dwt\events\paintlistener.d
	$(DMD) -c $(DFLAGS) dwt\events\paintlistener.d

selectionadapter.obj : dwt\events\selectionadapter.d
	$(DMD) -c $(DFLAGS) dwt\events\selectionadapter.d
	
selectionevent.obj : dwt\events\selectionevent.d
	$(DMD) -c $(DFLAGS) dwt\events\selectionevent.d

selectionlistener.obj : dwt\events\selectionlistener.d
	$(DMD) -c $(DFLAGS) dwt\events\selectionlistener.d
	
shelladapter.obj : dwt\events\shelladapter.d
	$(DMD) -c $(DFLAGS) dwt\events\shelladapter.d

shellevent.obj : dwt\events\shellevent.d
	$(DMD) -c $(DFLAGS) dwt\events\shellevent.d
	
shelllistener.obj : dwt\events\shelllistener.d
	$(DMD) -c $(DFLAGS) dwt\events\shelllistener.d

traverseevent.obj : dwt\events\traverseevent.d
	$(DMD) -c $(DFLAGS) dwt\events\traverseevent.d
	
traverselistener.obj : dwt\events\traverselistener.d
	$(DMD) -c $(DFLAGS) dwt\events\traverselistener.d
	
treeadapter.obj : dwt\events\treeadapter.d
	$(DMD) -c $(DFLAGS) dwt\events\treeadapter.d
	
treeevent.obj : dwt\events\treeevent.d
	$(DMD) -c $(DFLAGS) dwt\events\treeevent.d

treelistener.obj : dwt\events\treelistener.d
	$(DMD) -c $(DFLAGS) dwt\events\treelistener.d
	
typedevent.obj : dwt\events\typedevent.d
	$(DMD) -c $(DFLAGS) dwt\events\typedevent.d
	
verifyevent.obj : dwt\events\verifyevent.d
	$(DMD) -c $(DFLAGS) dwt\events\verifyevent.d
	
verifylistener.obj : dwt\events\verifylistener.d
	$(DMD) -c $(DFLAGS) dwt\events\verifylistener.d

	
# ########## dwt #############

dwt.obj : dwt\dwt.d
	$(DMD) -c $(DFLAGS) dwt\dwt.d

# ####### Accessibility ########
acc.obj : dwt\accessibility\acc.d

	$(DMD) -c $(DFLAGS) dwt\accessibility\acc.d
	
# dwtmain.obj : dwt\dwtmain.obj
#	$(DMD) -c $(DFLAGS) dwt\dwtmain.d